{% extends "admin/base_site.html" %}
{% load i18n admin_static %}

{% block extrastyle %}
  {{ block.super }}
{% endblock %}

{% block coltype %}colMS{% endblock %}

{% block bodyclass %}dashboard{% endblock %}

{% block breadcrumbs %}{% endblock %}

{% block content %}
  <div id="content-main">
    {% if app_list %}
      {% for app in app_list %}
        <div class="module">
          <table class="table-overview applist" summary="{% blocktrans with name=app.name %}Models available in the {{ name }} application.{% endblocktrans %}">
            <caption><a href="{{ app.app_url }}" class="section">
              {% blocktrans with name=app.name %}
                {{ name }}{% endblocktrans %}</a></caption>
            {% for model in app.models %}
              <tr>
                <th scope="row">{{ model.name }}</th>
                {% if model.admin_url %}
                  <td>
                    <a href="{{ model.admin_url }}" class="changelink icon">{% trans 'Change' %}</a>
                  </td>
                {% else %}
                  <td>&nbsp;</td>
                {% endif %}

                {% if model.add_url %}
                  <td><a href="{{ model.add_url }}" class="addlink icon"><i
                          class="icon-plus-sign icon-alpha75"></i>{% trans 'Add' %}
                  </a></td>
                {% else %}
                  <td>&nbsp;</td>
                {% endif %}
              </tr>
            {% endfor %}
          </table>
        </div>
      {% endfor %}
    {% else %}
      <p>{% trans "You don't have permission to edit anything." %}</p>
    {% endif %}
  </div>
{% endblock %}


{% block sidebar %}
  <div id="content-related">
    <div class="module" id="recent-actions-module">
      <h4 class="italic-title">{% trans 'My Actions' %}</h4>

      {% load log %}
      {% get_admin_log 10 as admin_log for_user user %}
      {% if not admin_log %}
        <p>{% trans 'None available' %}</p>
      {% else %}
        <ul class="actionlist">
          {% for entry in admin_log %}
            <li class="{% if entry.is_addition %}addlink{% endif %}{% if entry.is_change %}changelink{% endif %}{% if entry.is_deletion %}text-error{% endif %}">

              <i class="{% if entry.is_addition %}icon-plus{% endif %}{% if entry.is_change %}icon-pencil{% endif %}{% if entry.is_deletion %}icon-trash{% endif %} icon-alpha5"></i>

              {% spaceless %}
                {% if entry.is_addition %}{% trans 'added'|capfirst %}{% endif %}
                {% if entry.is_change %}{% trans 'changed'|capfirst %}{% endif %}
                {% if entry.is_deletion %}{% trans 'deleted'|capfirst %}{% endif %}

                {% if entry.content_type %}
                  <span class="mini quiet">{% filter capfirst %}
                    {% trans entry.content_type.name %}{% endfilter %}</span>
                {% else %}
                  <span class="mini quiet">{% trans 'Unknown content' %}</span>
                {% endif %}
              {% endspaceless %}&nbsp;

              {% if entry.is_deletion or not entry.get_admin_url %}
                <span class="color-grey">{{ entry.object_repr }}</span>
              {% else %}
                <a href="{{ entry.get_admin_url }}">{{ entry.object_repr }}</a>
              {% endif %}
            </li>
          {% endfor %}
        </ul>
      {% endif %}
    </div>
  </div>
{% endblock %}
