.header { //  border-top: 1px solid #494d4f;
    color: #d4d4d4;
    height: @header-height;
    overflow: hidden;
    text-shadow: 0 -1px #121414;

    .header-content {
        float: left;
        height: @header-height;
        overflow: hidden;
        padding: 7px 0 0 30px;
        line-height: normal;
        overflow: hidden;

        &.header-content-first {
            border-left: 1px solid #45494c;
            margin-right: 20px;
        }

        .time {
            font-weight: bold;
            color: white;
        }

        .header-column {
            float: left;
            i {
                margin-right: 10px;
            }
        }

    }

    #branding {
        height: @header-height;
        float: left;
        min-width: @left-column-width;
        border-right: 1px solid #2f3334;

        h1 {
            color: white;
            font-size: 18px;
            margin: 4px 15px 0 13px;
            padding: 0;
            text-shadow: 0 -1px #121414;
        }

        a {
            text-decoration: none;
            &:hover {
                h1 {
                    text-shadow: 0 0 10px rgba(255, 255, 255, 0.4);
//                    text-shadow: none;
                }
            }
        }
    }

    a {
        color: #92D1EE;
        text-decoration: none;
        &:hover {
            text-decoration: underline;
        }
        &.grey {
            color: #d4d4d4;
        }
    }

    #user-tools {
        padding: 12px 20px 0 0;
        float: right;
        .user-links {
            display: inline-block;
            margin-left: 15px;
        }
        .separator {
            color: #999;
            display: inline-block;
            margin: 0 5px;
        }
    }

    i { //  Switch to inverse icons
        background-image: url(../img/glyphicons-halflings-white-nav.png);
    }

    .horizontal-gradient(@header-bgcolor-1, @header-bgcolor-2);
}
