{% extends "admin/index.html" %}
{% load i18n %}
{% load url from future %}

{% if not is_popup %}
    {% block breadcrumbs %}
        <ul class="breadcrumb">
            <li><a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
                <span class="divider">&raquo;</span></li>
            {% for app in app_list %}
                <li class="active">{% blocktrans with app.name as name %}{{ name }}{% endblocktrans %}</li>
            {% endfor %}
        </ul>
    {% endblock %}
{% endif %}

{% block sidebar %}{% endblock %}
