/*!
 * DjangoSuit
 * http://djangosuit.com
 *
 * Copyright 2013 DjangoSuit.com
 * Licensed under the Creative Commons Attribution-NonCommercial 3.0
 * http://creativecommons.org/licenses/by-nc/3.0/
 *
 */
@import 'variables';
@import 'sticky-footer';
@import 'mixins';
@import 'header';
@import 'footer';
@import 'left-column';
@import 'ui/breadcrumb';
@import 'ui/table';
@import 'ui/actionlist';
@import 'ui/list';
@import 'ui/pagination';
@import 'ui/form';
@import 'ui/box';
@import 'ui/login';
@import 'ui/left-nav';
@import 'ui/calendar';
@import 'ui/datepicker';
@import 'ui/tabs';

body {
    background-color: @bgcolor;
    min-width: 960px;
    &.popup {
        min-width: inherit;
    }
}

#wrap {
    background: url(../img/bg_left_white.gif) top left repeat-y;
    .popup & {
        background: none;
    }
}

a {
    text-decoration: underline;
}

a:hover {
    text-decoration: none;
}

a.icon {
    i {
        margin-right: 5px;
    }
    margin-right: 10px;
    &:last-child {
        margin-right: 0;
    }
}

a.btn {
    text-decoration: none;
}

// White shadow
#content {
    h1, h2, h3, h4, alert {
        .white-shadow;
    }
}

// todo refactor this class to some h5 or h6 tag
.italic-title { //    font-style: italic;
    font-size: 17px;
    font-weight: normal;
    margin: 0 0 5px 5px;
}

.inner-two-columns {
    .inner-right-column {
        float: right;
        width: @right-column-width;
        &.fixed {
            position: fixed;
            right: 20px;
            top: 10px;
        }
    }
    .inner-center-column {
        margin-right: (@right-column-width + 20px);
        .tab-content {
            overflow: inherit;
            margin-bottom: 15px;
        }
    }
}

.icon-alpha5 {
    opacity: 0.5;
}
.icon-alpha75 {
    opacity: 0.75;
}
a:hover .icon-alpha5, a:hover .icon-alpha75 {
    opacity: 1;
}

.input-icon {
    position: relative;
    opacity: 0.2;
    margin-top: 2px;
    margin-left: -25px;
    margin-right: 8px;
}

.dashboard {
    #content {
        #content-main {
            float: left;
        }
        #content-related {
            margin-left: 20px;
            float: left;
            .actionlist {
                float: left;
            }
        }
    }
}

.colM {
    h1 {
        font-size: 20px;
        margin: 0 0 30px 5px;
    }
}

h1, h2, h3, h4, h5, h6 {
    .white-shadow;
}

h2 {
    font-weight: bold;
    font-size: 16px;
    line-height: 24px;
    margin: 0 0 0 10px;
}

a.append-icon i {
    margin-left: 5px;
}

// Hide content-title from regular lists and forms
.content-title {
    display: none;
}
.popup .content-title {
    display: block;
    margin: 0 0 10px 10px;
}

.errorlist {
    color: @red;
}

/* Column layout */
@cc-padding: (@padding * 2);
.suit-columns {
    padding-left: @left-column-width; /* LC fullwidth */
    .suit-column {
        position: relative;
        float: left;
    }
    .popup & {
        padding: 0;
    }
    padding-right: @cc-padding; /* RC fullwidth + CC padding */
    &.three-columns {

    }
}
#suit-center {
    padding: @padding; /* CC padding */
    width: 100%;
    .popup & {
        width: 94.9%;
        padding-bottom: 0;
    }
}
#suit-left {
    width: @left-column-width; /* LC width */
    right: (@left-column-width + @cc-padding); /* LC fullwidth + CC padding */
    margin-left: -100%;
}
#suit-right {
    width: 130px; /* RC width */
    padding: 0 10px; /* RC padding */
    margin-right: -190px; /* RC fullwidth + CC padding */
}

#push {
    clear: both;
}

@import 'print';
