.footer {

    color: #666;
    background-color: @footer-bgcolor;
    font-size: 11px;
    line-height: 1.5em;
    .white-shadow;

    .content {
        border-top: 5px solid #E1E3E5;

        .tools {
            float: left;
            padding: 15px 0 0 20px;
        }

        .branding {
            padding: 15px 0 0 0;
            margin: 0px auto;
            width: 200px;
            text-align: center;
        }

        .copyright {
            padding: 9px 20px 0 0;
            float: right;
            text-align: right;
        }
    }
}
