.datepicker {
    div & {
        margin: 0;
        padding: 0;
    }
    th, td {
        height: 16px !important;
    }
    input.input-small {
        width: 70px;
    }
}
.input-append.date .add-on i, .input-prepend.date .add-on i {
    width: 14px !important;
    height: 14px !important;
    display: inline-block !important;
}
