.actionlist {
    margin: 0;
    padding: 0;
    .border-radius(@border-radius);
    .grey-box-shadow;
    background: white;
    min-width: 200px;
    li {
        font-size: 11px;
        list-style: none;
        border-bottom: 1px solid lighten(@border-color-light, 3%);
        padding: 3px 10px;
        &:nth-child(2n) {
            background-color: @bgcolor-light;
        }
        &:first-child {
            padding-top: 5px;
        }
        &:last-child {
            padding-bottom: 5px;
            border: 0;
            .border-radius(null, null, @border-radius, @border-radius)
        }
        i {
            float: left;
            margin-right: 10px;
        }
        &.deletelink {
            .color-grey;
        }
        .deleted-entry {
            color: @text-color;
        }
    }
}
.applist td:last-child {
    min-width: 40px;
}
