/* Print styles */
@media print {
    html, body {
        -webkit-print-color-adjust: exact;
    }
    a[href]:after { content: "" !important; }

    select {
        -webkit-appearance: none;
    }

    #header, .left-column, #footer, #push, #suit-left, .actions,
    .inner-right-column, .add-row {
        display: none;
    }

    #wrap, body {
        background: transparent;
    }

    .suit-columns {
        padding-left: 0;
    }

    .two-columns .center-column {
        margin: 0;
    }

    .inner-two-columns .inner-center-column {
        margin-right: 0;
    }
}
