{% extends "suit/error_base.html" %}
{% load i18n %}

{% block title %}{% trans 'Server Error' %}{% endblock %}

{% block error %}{% trans 'error'|capfirst %} 500{% endblock %}

{% block content %}
  {% trans "There's been an error. It's been reported to the site administrators via e-mail and should be fixed shortly. Thanks for your patience." %}
{% endblock %}
