.object-tools {
    float: right;
    margin-bottom: 10px;
    .btn {
        margin-left: 5px;
    }
}

.actions {
    margin-bottom: 5px;
    label {
        display: inline;
    }
}
.below-actions .changelist-save {
    margin-top: -43px;
}

/* CHANGELISTS */

.change-list .hiddenfields {
    display: none;
}

/* ACTIONS */

#changelist .actions span.all,
#changelist .actions span.action-counter,
#changelist .actions span.clear,
#changelist .actions span.question {
    display: none;
}

#changelist #action-toggle {
    display: none;
}

/* Decided to hide action label */
#changelist .actions span.action-label {
    display: none;
}

#toolbar form {
    margin: 0 0 15px 0;
}

/* Search multi-line wrap top margin */
.search-container {
    margin-top: -5px;
    input, select {
        margin-top: 5px;
    }
    input[type="radio"], input[type="checkbox"] {
        margin-top: 3px;
    }
    .result-count {
        display: inline-block;
        margin: 5px 0 0 5px;
        white-space: nowrap;
        vertical-align: middle;
    }
}
