/* Django admin original class - support for Admin original html structure */
.breadcrumbs {
    font-size: 14px;
    padding: 8px 15px 8px 10px;
    margin: -5px 0 15px;
    background-color: #f5f5f5;
    .border-radius(4px);
    .white-shadow;
    color: #666;
    &>a {
        display: inline-block;
        padding: 0 3px;
        text-shadow: 0 1px 0 #ffffff;
        font-weight: normal;
        &>.divider {
            padding: 0 5px;
            color: #ccc;
        }
        &>.active {
            font-weight: bold;
            color: #666;
        }
    }
}

.breadcrumbs > a > .divider {
}

.breadcrumbs > .active {
    color: #999999;
}

/* NEW CLASS based on BS */
.breadcrumb {
    margin: -5px 0 15px;
    font-size: 14px;
    .white-shadow;
    li {
        a {
            text-decoration: none;
            &:hover {
                text-decoration: underline;
            }
        }
        &.active, &.active a {
            font-weight: bold;
            color: #333;
        }
    }
    &.toplinks {
        font-size: 12px;
        margin-bottom: 12px;
    }
}
