{% extends "admin/object_history.html" %}
{% load i18n %}


{% block content %}
<div id="content-main">

    <div class="alert alert-info">{% blocktrans %}Choose a date from the list below to revert to a previous version of this object.{% endblocktrans %}</div>

    <div class="module">
        {% if action_list %}
        <table id="change-history" class="table table-bordered table-condensed table-striped">
            <thead>
            <tr>
                <th scope="col">{% trans 'Date/time' %}</th>
                <th scope="col">{% trans 'User' %}</th>
                <th scope="col">{% trans 'Comment' %}</th>
            </tr>
            </thead>
            <tbody>
            {% for action in action_list %}
            <tr>
                <th scope="row"><a href="{{action.url}}">{{action.revision.date_created}}</a></th>
                <td>
                    {% if action.revision.user %}
                    {{action.revision.user.username}}
                    {% if action.revision.user.first_name %} ({{action.revision.user.first_name}} {{action.revision.user.last_name}}){% endif %}
                    {% endif %}
                </td>
                <td>{{action.revision.comment|linebreaksbr|default:""}}</td>
            </tr>
            {% endfor %}
            </tbody>
        </table>
        {% else %}
        <div class="alert alert-warn">{% trans "This object doesn't have a change history. It probably wasn't added via this admin site." %}</div>
        {% endif %}
    </div>
</div>
{% endblock %}
